@@ -1,26 +1,3 @@
-# Copyright (c) 2014  Timm Murray
-# All rights reserved.
-# 
-# Redistribution and use in source and binary forms, with or without 
-# modification, are permitted provided that the following conditions are met:
-# 
-#     * Redistributions of source code must retain the above copyright notice, 
-#       this list of conditions and the following disclaimer.
-#     * Redistributions in binary form must reproduce the above copyright 
-#       notice, this list of conditions and the following disclaimer in the 
-#       documentation and/or other materials provided with the distribution.
-# 
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
-# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
-# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
-# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
-# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
-# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
-# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
-# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
-# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
-# POSSIBILITY OF SUCH DAMAGE.
 package UAV::Pilot::Commands;
 use v5.14;
 use Moose;
@@ -29,7 +6,10 @@ use File::Spec;
 
 use constant MOD_EXTENSION => '.uav';
 
-
+has 'device' => (
+    is   => 'ro',
+    does => 'UAV::Pilot::Control',
+);
 has 'lib_dirs' => (
     is      => 'ro',
     isa     => 'ArrayRef[Str]',
@@ -39,29 +19,8 @@ has 'lib_dirs' => (
         add_lib_dir => 'push',
     },
 );
-has 'condvar' => (
-    is  => 'ro',
-    isa => 'AnyEvent::CondVar',
-);
-has 'controller_callback_ardrone' => (
-    is  => 'ro',
-    isa => 'CodeRef',
-);
-has 'controller_callback_wumpusrover' => (
-    is  => 'ro',
-    isa => 'CodeRef',
-);
-has 'quit_subs' => (
-    traits  => ['Array'],
-    is      => 'ro',
-    isa     => 'ArrayRef[CodeRef]',
-    default => sub {[]},
-    handles => {
-        '_push_quit_sub' => 'push',
-    },
-);
 
-our $s;
+our ($dev, $s);
 
 #
 # Sole command that can run without loading other libraries
@@ -69,7 +28,6 @@ our $s;
 sub load ($;$)
 {
     my ($mod_name, $args) = @_;
-    $$args{condvar} = $s->condvar unless exists $$args{condvar};
     $s->load_lib( $mod_name, $args );
 }
 
@@ -83,27 +41,20 @@ sub run_cmd
     }
     return 1 unless defined $cmd;
 
-    $s = $self;
+    $s   = $self;
+    $dev = $self->device;
     eval $cmd;
     die $@ if $@;
 
     return 1;
 }
 
-sub quit
-{
-    my ($self) = @_;
-    $_->() for @{ $self->{quit_subs} };
-    return 1;
-}
-
 
 sub load_lib
 {
     my ($self, $mod_name, $args) = @_;
     my @search_dirs = @{ $self->lib_dirs };
     my $mod_file = $mod_name . $self->MOD_EXTENSION;
-    my $host = delete $$args{host};
 
     my $found = 0;
     foreach my $dir (@search_dirs) {
@@ -142,7 +93,7 @@ sub _compile_mod
 
     $pack = ref($self) unless defined $pack;
     if( my $call = $pack->can( 'uav_module_init' ) ) {
-        $call->( $pack, $self, $args );
+        $call->( $pack, $args );
 
         # Clear uav_module_init.  Would prefer a solution without eval( STRING ), 
         # though a symbol table manipulation method may be considered just as evil.
@@ -150,10 +101,6 @@ sub _compile_mod
         eval $del_str;
     }
 
-    if( my $quit_call = $pack->can( 'uav_module_quit' ) ) {
-        $self->_push_quit_sub( $quit_call );
-    }
-
     return 1;
 }
 
@@ -173,8 +120,6 @@ __END__
     my $device; # Some UAV::Pilot::Control instance, defined elsewhere
     my $cmds = UAV::Pilot::Commands->new({
         device => $device,
-        controller_callback_ardrone     => \&make_ardrone_controller,
-        controller_callback_wumpusrover => \&make_wumpusrover_controller,
     });
     
     $cmds->load_lib( 'ARDrone' );
@@ -191,21 +136,10 @@ REPL shells.
 =head2 new
 
     new({
-        condvar                         => $cv,
-        controller_callback_ardrone     => sub { ... },
-        controller_callback_wumpusrover => sub { .. },
+        device => $device
     })
 
-Constructor.  The C<condvar> parameter is an C<AnyEvent::Condvar>.
-
-The C<controller_callback_*> parameters take a sub ref.  The subroutines take 
-a the parameters C<($cmd, $cv, $easy_event)>, where C<$cmd> is this 
-C<UAV::Pilot::Commands> instance, C<$cv> is the condvar passed above, and 
-C<$easy_event> is an C<UAV::Pilot::EasyEvent> instance.  It should return a 
-C<UAV::Pilot::Control> object of the associated type (generally one of the 
-C<*::Event> types with C<init_event_loop()> called).
-
-Note that this API is likely to change to a factory pattern in the near future.
+Constructor.  Takes a L<UAV::Pilot::Control> instance.
 
 =head2 load_lib
 
@@ -281,5 +215,3 @@ parens.
 The method C<uav_module_init()> is called with the package name as the first argument.  
 Subsquent arguments will be the hashref passed to C<load()/load_lib()>.  After being called,
 this sub will be deleted from the package.
-
-The method C<uav_module_quit()> is called when the REPL is closing.
